package com.atguigu.ssyx.acl.service.impl;

import com.atguigu.common.utils.PermissionHelper;
import com.atguigu.ssyx.acl.mapper.PermissionMapper;
import com.atguigu.ssyx.acl.service.PermissionService;
import com.atguigu.ssyx.acl.service.RolePermissionService;
import com.atguigu.ssyx.acl.service.module.PermissionServiceModule;
import com.atguigu.ssyx.model.acl.Permission;
import com.atguigu.ssyx.model.acl.RolePermission;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class PermissionServiceImpl extends ServiceImpl<PermissionMapper, Permission> implements PermissionService {
    @Autowired
    private PermissionServiceModule permissionServiceModule;
    @Autowired
    private RolePermissionService rolePermissionService;

    /**
     * 获取所有菜单列表
     *
     * @return 权限列表
     */
    @Override
    public List<Permission> queryAllMenu() {
        // 转换要求数据格式
        return PermissionHelper.buildPermissions(list());
    }

    /**
     * 递归删除
     *
     * @param id 删除ID
     */
    @Override
    public void removeChildById(Long id) {
        ArrayList<Long> idList = new ArrayList<>();

        // 获取菜单下子菜单
        permissionServiceModule.getAllPermissionId(id, idList);

        // 调用方法根据多个菜单ID删除
        baseMapper.deleteBatchIds(idList);
    }

    /**
     * 查询所有菜单和角色分配菜单
     *
     * @param roleId 角色Id
     * @return 权限列表
     */
    @Override
    public List<Permission> findMenuByRoleId(Long roleId) {
        List<Permission> permissionList = list();

        List<RolePermission> rolePermissionList = rolePermissionService.list(
                Wrappers.<RolePermission>lambdaQuery().eq(RolePermission::getRoleId, roleId)
        );

        List<Long> permissionIdList = rolePermissionList.stream().map(RolePermission::getPermissionId).collect(Collectors.toList());

        permissionList.forEach(permission -> {
            if (permissionIdList.contains(permission.getId())) {
                permission.setSelect(true);
            }
            permission.setSelect(false);
        });

        return PermissionHelper.buildPermissions(permissionList);
    }

    /**
     * 查询所有菜单和角色分配菜单
     *
     * @param roleId      角色Id
     * @param permissions 分配权限Id
     */
    @Override
    public void doAssign(Long roleId, List<Long> permissions) {
        // 先删除之前分配的角色
        rolePermissionService.remove(Wrappers.<RolePermission>lambdaQuery().eq(RolePermission::getRoleId, roleId));
        ArrayList<RolePermission> list = new ArrayList<>();

        permissions.forEach(permissionId -> {
            RolePermission rolePermission = new RolePermission();
            rolePermission.setPermissionId(permissionId);
            rolePermission.setRoleId(roleId);
            list.add(rolePermission);
        });

        rolePermissionService.saveBatch(list);
    }
}
