package com.atguigu.ssyx.activity.service;

import com.atguigu.ssyx.model.activity.ActivityInfo;
import com.atguigu.ssyx.model.order.CartInfo;
import com.atguigu.ssyx.model.product.SkuInfo;
import com.atguigu.ssyx.vo.activity.ActivityRuleVo;
import com.atguigu.ssyx.vo.order.OrderConfirmVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;
import java.util.Map;

public interface ActivityInfoService extends IService<ActivityInfo> {

    /**
     * 获取分页列表
     *
     * @param pageParam 分页查询条件
     * @return 分页结果
     */
    IPage<ActivityInfo> selectPage(Page<ActivityInfo> pageParam);

    /**
     * 获取活动规则
     *
     * @param id 当前id
     * @return 返回集合
     */
    Map<String, Object> findActivityRuleList(Long id);

    /**
     * 新增活动规则
     *
     * @param activityRuleVo 活动规则
     */
    void saveActivityRule(ActivityRuleVo activityRuleVo);

    /**
     * 根据关键字获取sku列表，活动使用
     *
     * @param keyword 关键字
     * @return 活动列表
     */
    List<SkuInfo> findSkuInfoByKeyword(String keyword);

    /**
     * * 根据skuId列表获取促销信息
     *
     * @param skuIdList 列表
     * @return Map<Long, List < String>>
     */
    Map<Long, List<String>> findActivity(List<Long> skuIdList);

    /**
     * * 根据skuId获取促销与优惠券信息
     *
     * @param skuId  商品id
     * @param userId 用户id
     * @return 营销的活动
     */
    Map<String, Object> findActivityAndCoupon(Long skuId, Long userId);

    /**
     * * 获取购物车满足条件的促销与优惠券信息
     *
     * @param cartInfoList 购物车信息列表
     * @param userId       用户ID
     * @return OrderConfirmVo
     */
    OrderConfirmVo findCartActivityAndCoupon(List<CartInfo> cartInfoList, Long userId);
}
