package com.atguigu.ssyx.activity.service.module;

import com.atguigu.ssyx.enums.CouponRangeType;
import com.atguigu.ssyx.model.activity.CouponRange;
import com.atguigu.ssyx.model.order.CartInfo;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Component;

import java.util.*;
import java.util.stream.Collectors;

@Component
public class CouponInfoServiceModule {
    @NotNull
    private static Set<Long> getLongs(List<CartInfo> cartInfoList, Map.Entry<Long, List<CouponRange>> entry) {
        List<CouponRange> couponRangeList = entry.getValue();

        Set<Long> skuIdSet = new HashSet<>();
        for (CartInfo cartInfo : cartInfoList) {
            for (CouponRange couponRange : couponRangeList) {
                if (CouponRangeType.SKU == couponRange.getRangeType() && couponRange.getRangeId() == cartInfo.getSkuId().intValue()) {
                    skuIdSet.add(cartInfo.getSkuId());
                } else if (CouponRangeType.CATEGORY == couponRange.getRangeType() && couponRange.getRangeId() == cartInfo.getCategoryId().intValue()) {
                    skuIdSet.add(cartInfo.getSkuId());
                }
            }
        }
        return skuIdSet;
    }

    public Map<Long, List<Long>> findCouponIdToSkuIdMap(List<CartInfo> cartInfoList, List<CouponRange> couponRangesList) {
        Map<Long, List<Long>> couponIdToSkuIdMap = new HashMap<>();
        // 优惠券id对应的范围列表
        Map<Long, List<CouponRange>> couponIdToCouponRangeListMap = couponRangesList.stream().collect(Collectors.groupingBy(couponRange -> couponRange.getCouponId()));
        for (Map.Entry<Long, List<CouponRange>> entry : couponIdToCouponRangeListMap.entrySet()) {
            Long couponId = entry.getKey();
            Set<Long> skuIdSet = getLongs(cartInfoList, entry);
            couponIdToSkuIdMap.put(couponId, new ArrayList<>(skuIdSet));
        }
        return couponIdToSkuIdMap;
    }
}
