package com.atguigu.ssyx.home.service.impl;

import com.atguigu.ssyx.client.ActivityFeignClient;
import com.atguigu.ssyx.client.product.ProductFeignClient;
import com.atguigu.ssyx.client.search.SearchFeignClient;
import com.atguigu.ssyx.home.service.ItemService;
import com.atguigu.ssyx.vo.product.SkuInfoVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ThreadPoolExecutor;

@Service
public class ItemServiceImpl implements ItemService {
    @Autowired
    private ThreadPoolExecutor threadPoolExecutor;
    @Autowired
    private ProductFeignClient productFeignClient;
    @Autowired
    private ActivityFeignClient activityFeignClient;
    @Autowired
    private SearchFeignClient searchFeignClient;

    /**
     * * 获取sku详细信息
     *
     * @param userId 用户id
     * @return sku详细信息
     */
    @Override
    public Map<String, Object> getItem(Long skuId, Long userId) {
        HashMap<String, Object> result = new HashMap<>();

        CompletableFuture<SkuInfoVo> skuInfoVoFuture = CompletableFuture.supplyAsync(() -> {
            // 远程调用实现
            SkuInfoVo skuInfoVo = productFeignClient.getSkuInfoVo(skuId);
            result.put("skuInfoVo", skuInfoVo);
            return skuInfoVo;
        }, threadPoolExecutor);

        // 获取优惠卷信息
        CompletableFuture<Void> activityFuture = CompletableFuture.runAsync(() -> {
            Map<String, Object> activityMap = activityFeignClient.findActivityAndCoupon(skuId, userId);
            result.putAll(activityMap);
        }, threadPoolExecutor);

        // 更新商品热度
        CompletableFuture<Void> voidCompletableFuture = CompletableFuture.runAsync(() -> {
            searchFeignClient.incrHotScore(skuId);
        }, threadPoolExecutor);

        // 任务组合
        CompletableFuture.allOf(skuInfoVoFuture, activityFuture, voidCompletableFuture).join();
        return result;
    }
}
