package com.atguigu.ssyx.product.service.impl;

import cn.hutool.core.date.DateUtil;
import com.atguigu.ssyx.common.properties.MinioProperties;
import com.atguigu.ssyx.product.service.FileUploadService;
import io.minio.BucketExistsArgs;
import io.minio.MakeBucketArgs;
import io.minio.MinioClient;
import io.minio.PutObjectArgs;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.Date;
import java.util.UUID;


@Service
@Slf4j
public class FileUploadServiceImpl implements FileUploadService {
    @Autowired
    private MinioProperties properties;
    @Autowired
    private MinioClient minioClient;

    /**
     * 文件上传
     *
     * @param file 上传的文件
     * @return 文件路径
     */
    @Override
    public String uploadFile(MultipartFile file) {
        String bucketName = properties.getBucketName();
        String dir = DateUtil.format(new Date(), "yyyy-MM-dd");
        String uuid = UUID.randomUUID().toString();
        String filename = dir + "/" + uuid + "-" + file.getOriginalFilename();

        try {
            boolean bucketExists = minioClient.bucketExists(BucketExistsArgs.builder().bucket(bucketName).build());
            if (!bucketExists) {
                log.warn("minio桶不存在：{}", bucketName);
                minioClient.makeBucket(MakeBucketArgs.builder().bucket(bucketName).build());
            }

            // 存入图片
            minioClient.putObject(PutObjectArgs.builder()
                    .bucket(bucketName)
                    .object(filename)
                    .stream(file.getInputStream(), file.getSize(), -1).build());

            return properties.getEndpointUrl() + "/" + properties.getBucketName() + "/" + filename;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
